@@ -111,6 +111,10 @@ class SmartPrintView(BrowserView):
             s = s.replace(' ', '_')
             return s
 
+        filename = os.path.abspath(filename)
+        if not filename.startswith(tempfile.gettempdir()):
+            raise RuntimeError('Can not download %s' % filename)
+
         type, enc = guess_content_type(filename)
         base, ext = os.path.splitext(os.path.basename(filename))
         id = normalize(self.context.getId())
@@ -119,6 +123,7 @@ class SmartPrintView(BrowserView):
         R.setHeader('content-type', type)
         R.setHeader('content-length', os.stat(filename)[6])
         R.setHeader('content-disposition', 'attachment; filename=%s%s' % (id, ext))
+        filename = os.path.abspath(filename)
         return filestream_iterator(filename, 'rb')
 
 
